library erp_local_database;

import 'dart:async';
import 'dart:convert';
import 'package:floor/floor.dart';
import 'package:sqflite/sqflite.dart' as sqflite;

import 'account_management.dart';
import 'permission_management.dart';
import 'store_management.dart';

part 'database.g.dart'; // the generated code will be there
part 'converters.dart';

@TypeConverters([
  DateTimeConverter,
  DateTimeNullSafetyConverter,
  ListStringConverter,
  ListStringNullSafetyConverter
])
@Database(version: 1, entities: [
  // Permission management
  BranchModel, UserModel, BranchUserModel, PermissionModel, UserRoleModel,
  BranchUserPermissionModel, SessionModel, DeviceModel,
  // Account management
  AccountModel, AccountTypeModel, AccountLevelModel, AccountGroupModel,
  AccountCurrencyModel, ReceiptModel, ReceiptTypeModel, CurrencyModel,
  ReceiptDetailModel,
  // Store management
  StoreModel, ProductModel, ProductCatagoryModel, MeasureUnitModel,
  ProductMeasureModel, ProductStorageModel, ProductTypeModel,
])
abstract class ERPDBContext extends FloorDatabase {
  // Permission management
  BranchDbSet get branch;
  UserDbSet get user;
  UserRoleDbSet get userRole;
  PermissionDbSet get permission;
  BranchUserDbSet get branchUser;
  BranchUserPermissionDbSet get branchUserPermission;
  SessionDbSet get session;
  DeviceDbSet get device;
  // Account management
  AccountGroupDbSet get accountGroup;
  AccountTypeDbSet get accountType;
  AccountLevelDbSet get accountLevel;
  CurrencyDbSet get currency;
  AccountDbSet get account;
  AccountCurrencyDbSet get accountCurrency;
  ReceiptTypeDbSet get receiptType;
  ReceiptDbSet get receipt;
  ReceiptDetailDbSet get receiptDetail;
  // Store management
  StoreDbSet get store;
  ProductCatagoryDbSet get productCatagory;
  MeasureUnitDbSet get measureUnit;
  ProductTypeDbSet get productType;
  ProductDbSet get product;
  ProductMeasureDbSet get productMeasure;
  ProductStorageDbSet get productStorage;
}
